@@ -462,17 +462,17 @@ def streams_client(uri: str) -> StreamsClient:
 
 @tp.overload
 def connection(
-        f: tp.Callable[P, Coroutine[V, S, T]]
+        coro: tp.Callable[P, Coroutine[V, S, T]]
 ) -> tp.Callable[P, Coroutine[V, S, T]]: ...
 
 @tp.overload
 def connection(
-        f: tp.Callable[P, AsyncGenerator[T, S]]
+        coro: tp.Callable[P, AsyncGenerator[T, S]]
     ) -> tp.Callable[P, AsyncGenerator[T, S]]:
     ...
 
 def connection(
-        f: tp.Callable[P, Coroutine[V, S, T]]
+        coro: tp.Callable[P, Coroutine[V, S, T]]
            | tp.Callable[P, AsyncGenerator[T, S]]
 ) -> tp.Callable[P, Coroutine[V, S, T]] \
      | tp.Callable[P, AsyncGenerator[T, S]]:
@@ -484,10 +484,10 @@ def connection(
     Streams client has to be the first parameter of coroutine `f`. On exit
     the streams client is disconnected using connection manager API.
 
-    :param f: Coroutine using RabbitMQ Streams client.
+    :param coro: Coroutine using RabbitMQ Streams client.
     """
-    f_coro = tp.cast(tp.Callable[P, Coroutine[V, S, T]], f)
-    f_gen = tp.cast(tp.Callable[P, AsyncGenerator[T, S]], f)
+    f_coro = tp.cast(tp.Callable[P, Coroutine[V, S, T]], coro)
+    f_gen = tp.cast(tp.Callable[P, AsyncGenerator[T, S]], coro)
     async def wrapper(*args: P.args, **kw: P.kwargs) -> T:
         client = tp.cast(
             ConnectionManager[RabbitMQStreamsProtocol], args[0]
@@ -508,9 +508,9 @@ def connection(
         finally:
             await client.disconnect()
 
-    if inspect.iscoroutinefunction(f):
+    if inspect.iscoroutinefunction(coro):
         return wrapper
-    elif inspect.isasyncgenfunction(f):
+    elif inspect.isasyncgenfunction(coro):
         return wrapper_gen
     else:
         raise RbFlyError(
