@@ -209,7 +209,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
             logger.info('rabbitmq stream created: {}'.format(stream))
 
         # always send metadata query for a stream
-        return (await self.query_stream_metadata(stream))
+        return await self.query_stream_metadata(stream)
 
     @retry(ProtocolError, predicate=is_stream_na, retry_after=1)
     async def create_publisher(
@@ -244,7 +244,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
            - `declare_publisher`
         """
         data = codec.FMT_PUBLISHER_ID.pack(publisher_id)
-        return (await self.send_request(const.KEY_DELETE_PUBLISHER, data))
+        return await self.send_request(const.KEY_DELETE_PUBLISHER, data)
 
     @tp.overload
     async def publish(
@@ -289,7 +289,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
 
         frame = self.encoder.encode_publish(publisher_id, message_id, *messages, amqp=amqp)
         self.send_frame(frame)
-        return (await task)
+        return await task
 
     @retry(ProtocolError, predicate=is_stream_na, retry_after=1)
     async def subscribe(
@@ -320,7 +320,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         task = self._loop.create_future()
         data = codec.encode_subscribe(sid, stream, offset, self.credit)
         self._subscriptions[sid] = ReceivedMessages(task, value, MessageQueue(), amqp)
-        return (await self.send_request(const.KEY_SUBSCRIBE, data))
+        return await self.send_request(const.KEY_SUBSCRIBE, data)
 
     async def read_stream(self, subscription_id: int, amqp: bool) -> MessageQueue:
         """
@@ -353,14 +353,14 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         """
         data = codec.FMT_SUBSCRIPTION_ID.pack(subscription_id)
         del self._subscriptions[subscription_id]
-        return (await self.send_request(const.KEY_UNSUBSCRIBE, data))
+        return await self.send_request(const.KEY_UNSUBSCRIBE, data)
 
     async def send_close(self) -> tp.Any:
         """
         Send close request to RabbitMQ Streams broker.
         """
         data = codec.encode_close(1, 'OK')
-        return (await self.send_request(const.KEY_CLOSE, data))
+        return await self.send_request(const.KEY_CLOSE, data)
 
     #
     # protocol implementation details
@@ -371,13 +371,13 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         Send peer properties to RabbitMQ Streams broker.
         """
         data = codec.encode_properties(PEER_PROPERTIES)
-        return (await self.send_request(const.KEY_PEER_PROPERTIES, data))
+        return await self.send_request(const.KEY_PEER_PROPERTIES, data)
 
     async def send_sasl_handshake(self) -> tp.Any:
         """
         Send SASL handshake to RabbitMQ Streams broker.
         """
-        return (await self.send_request(const.KEY_SASL_HANDSHAKE, b''))
+        return await self.send_request(const.KEY_SASL_HANDSHAKE, b'')
 
     async def send_sasl_authentication(
             self, username: str, password: str
@@ -386,7 +386,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         Send SASL authentication message to RabbitMQ Streams broker.
         """
         data = codec.sasl_authenticatation_data(username, password)
-        return (await self.send_request(const.KEY_SASL_AUTHENTICATE, data))
+        return await self.send_request(const.KEY_SASL_AUTHENTICATE, data)
 
     async def send_open(self, vhost: str) -> tp.Any:
         """
@@ -405,7 +405,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         :param stream: Stream name.
         """
         data = codec.encode_stream(stream)
-        return (await self.send_request(const.KEY_CREATE_STREAM, data))
+        return await self.send_request(const.KEY_CREATE_STREAM, data)
 
     async def query_stream_metadata(self, stream: str) -> tp.Any:
         """
@@ -414,7 +414,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         :param stream: Stream name.
         """
         data = codec.encode_metadata_query(stream)
-        return (await self.send_request(const.KEY_METADATA_QUERY, data))
+        return await self.send_request(const.KEY_METADATA_QUERY, data)
 
     async def declare_publisher(
         self, publisher_id: int, publisher_ref: str, stream: str
@@ -432,7 +432,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
            - `delete_publisher`
         """
         data = codec.declare_publisher(publisher_id, publisher_ref, stream)
-        return (await self.send_request(const.KEY_DECLARE_PUBLISHER, data))
+        return await self.send_request(const.KEY_DECLARE_PUBLISHER, data)
 
     async def query_offset(self, stream: str, reference: str) -> int:
         """
@@ -600,7 +600,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
                 'request sent, key=0x{:02x}, correlation_id={}'
                 .format(key, correlation_id)
             )
-        return (await task)
+        return await task
 
     def create_waiter(self, key: int) -> asyncio.Future[None]:
         """
